summaryrefslogtreecommitdiff
path: root/src/script/api/script_info_docs.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/script/api/script_info_docs.hpp')
-rw-r--r--src/script/api/script_info_docs.hpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/script/api/script_info_docs.hpp b/src/script/api/script_info_docs.hpp
index be5d0cec6..36d2b859a 100644
--- a/src/script/api/script_info_docs.hpp
+++ b/src/script/api/script_info_docs.hpp
@@ -203,7 +203,7 @@ public:
/** Miscellaneous flags for Script settings. */
enum ScriptConfigFlags {
CONFIG_NONE, ///< Normal setting.
- CONFIG_RANDOM, ///< When randomizing the Script, pick any value between min_value and max_value.
+ CONFIG_RANDOM, ///< When randomizing the Script, pick any value between min_value and max_value (inclusive).
CONFIG_BOOLEAN, ///< This value is a boolean (either 0 (false) or 1 (true) ).
CONFIG_INGAME, ///< This setting can be changed while the Script is running.
CONFIG_DEVELOPER, ///< This setting will only be visible when the Script development tools are active.
@@ -230,8 +230,8 @@ public:
* - custom_value The default value if the custom difficulty level
* is selected. Required.
* - random_deviation If this property has a nonzero value, then the
* actual value of the setting in game will be
* user_configured_value + random(-random_deviation, random_deviation).
* Not allowed if the CONFIG_RANDOM flag is set, otherwise optional.
* - step_size The increase/decrease of the value every time the user
* clicks one of the up/down arrow buttons. Optional, default is 1.
@@ -230,8 +230,8 @@ public:
* is selected. Required.
* - random_deviation If this property has a nonzero value, then the
- * actual value of the setting in game will be
- * user_configured_value + random(-random_deviation, random_deviation).
+ * actual value of the setting in game will be randomized in the range
+ * [user_configured_value - random_deviation, user_configured_value + random_deviation] (inclusive).
* Not allowed if the CONFIG_RANDOM flag is set, otherwise optional.
* - step_size The increase/decrease of the value every time the user